@@ -5,7 +5,8 @@ import re
 
 def _line_regexp():
     """Regular expression to match a traceback file line"""
-    return re.compile(r'''\s*
+    return re.compile(
+        r"""\s*
         File\s
         (
             (
@@ -19,7 +20,9 @@ def _line_regexp():
         ,\sline\s
         (?P<line_number>[0-9]+)
         ,.in..*
-    ''', re.VERBOSE)
+    """,
+        re.VERBOSE,
+    )
 
 
 def parse_line(string):
@@ -27,9 +30,9 @@ def parse_line(string):
     match = _line_regexp().match(string)
     if match:
         matches = match.groupdict()
-        line_number = int(matches['line_number'])
-        path_to_python = matches['path_to_python']
-        spaceless_path_to_python = matches['spaceless_path_to_python']
+        line_number = int(matches["line_number"])
+        path_to_python = matches["path_to_python"]
+        spaceless_path_to_python = matches["spaceless_path_to_python"]
         if path_to_python:
             return path_to_python, line_number
         elif spaceless_path_to_python:
