@@ -1,6 +1,6 @@
 """Empty values of various types"""
 
 none = None
-string = ''
+string = ""
 integer = 0
 real = 0.0
